@@ -4,29 +4,19 @@
  */
 
 #pragma once
-#include <aws/ec2/EC2_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/ec2/EC2_EXPORTS.h>
 
-namespace Aws
-{
-namespace EC2
-{
-namespace Model
-{
-  enum class IpamManagementState
-  {
-    NOT_SET,
-    managed,
-    unmanaged,
-    ignored
-  };
+namespace Aws {
+namespace EC2 {
+namespace Model {
+enum class IpamManagementState { NOT_SET, managed, unmanaged, ignored };
 
-namespace IpamManagementStateMapper
-{
+namespace IpamManagementStateMapper {
 AWS_EC2_API IpamManagementState GetIpamManagementStateForName(const Aws::String& name);
 
 AWS_EC2_API Aws::String GetNameForIpamManagementState(IpamManagementState value);
-} // namespace IpamManagementStateMapper
-} // namespace Model
-} // namespace EC2
-} // namespace Aws
+}  // namespace IpamManagementStateMapper
+}  // namespace Model
+}  // namespace EC2
+}  // namespace Aws
