@@ -4,28 +4,19 @@
  */
 
 #pragma once
-#include <aws/ec2/EC2_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/ec2/EC2_EXPORTS.h>
 
-namespace Aws
-{
-namespace EC2
-{
-namespace Model
-{
-  enum class IpamPoolPublicIpSource
-  {
-    NOT_SET,
-    amazon,
-    byoip
-  };
+namespace Aws {
+namespace EC2 {
+namespace Model {
+enum class IpamPoolPublicIpSource { NOT_SET, amazon, byoip };
 
-namespace IpamPoolPublicIpSourceMapper
-{
+namespace IpamPoolPublicIpSourceMapper {
 AWS_EC2_API IpamPoolPublicIpSource GetIpamPoolPublicIpSourceForName(const Aws::String& name);
 
 AWS_EC2_API Aws::String GetNameForIpamPoolPublicIpSource(IpamPoolPublicIpSource value);
-} // namespace IpamPoolPublicIpSourceMapper
-} // namespace Model
-} // namespace EC2
-} // namespace Aws
+}  // namespace IpamPoolPublicIpSourceMapper
+}  // namespace Model
+}  // namespace EC2
+}  // namespace Aws
