@@ -4,28 +4,19 @@
  */
 
 #pragma once
-#include <aws/ec2/EC2_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/ec2/EC2_EXPORTS.h>
 
-namespace Aws
-{
-namespace EC2
-{
-namespace Model
-{
-  enum class SnapshotAttributeName
-  {
-    NOT_SET,
-    productCodes,
-    createVolumePermission
-  };
+namespace Aws {
+namespace EC2 {
+namespace Model {
+enum class SnapshotAttributeName { NOT_SET, productCodes, createVolumePermission };
 
-namespace SnapshotAttributeNameMapper
-{
+namespace SnapshotAttributeNameMapper {
 AWS_EC2_API SnapshotAttributeName GetSnapshotAttributeNameForName(const Aws::String& name);
 
 AWS_EC2_API Aws::String GetNameForSnapshotAttributeName(SnapshotAttributeName value);
-} // namespace SnapshotAttributeNameMapper
-} // namespace Model
-} // namespace EC2
-} // namespace Aws
+}  // namespace SnapshotAttributeNameMapper
+}  // namespace Model
+}  // namespace EC2
+}  // namespace Aws
